
// READ  MIDI KNOBS

void M_read_knobs() {

  int dots_M; // switch control for octave of midi notes
  int Update; // loop to update EEPROM

  // READ MIDI Channel KNOB

  M_displayDelay --; // display and EEPROM write countdown

  chknob = EncodeReadN(); // set MIDI Channel
  //Serial.print(chknob);
  if (chknob != 0 && time - last_read_M > read_delay)
  {
    //turn off all notes before changing channel
    for (a = 0; a < 4; a++)
    {
      playMIDIOff();
      runningStatus = 1;
    }

    // update midi channel and check it's within between 1 and 16

    MIDI_chan = MIDI_chan + chknob;
    if (MIDI_chan > 16) {
      MIDI_chan = 16;
    }
    if (MIDI_chan < 1) {
      MIDI_chan = 1;
    }

    last_read_M = millis();
    M_displayDelay = displayDelay;
    runningStatus = 0;
    dots_octave = 0;
    dots = MIDI_chan;
    barGraph();                //Display MIDI Chan number on bottom 2 rows
  }

  // READ MIDI Velocity KNOB ----------------------------------------

  vlknob = EncodeReadK();
  if (vlknob != 0 && time - last_read_M > read_delay)
  {
    // Update velocity setting and make sure it's between 1 and 127
    if (MIDI_sets[activeMIDI][0] < 6 && vlknob < 0)
    {
      MIDI_sets[activeMIDI][0] = 5;
    }
    MIDI_sets[activeMIDI][0] = MIDI_sets[activeMIDI][0] + (vlknob * 5); // step by 5
    if (MIDI_sets[activeMIDI][0] > 127) {
      MIDI_sets[activeMIDI][0] = 127;
    }
    //if (MIDI_sets[activeMIDI][0] < 5) {
    // MIDI_sets[activeMIDI][0] = 0;
    //}

    last_read_M = millis();
    M_displayDelay = displayDelay;
    dots_octave = 0;
    dots = MIDI_sets[activeMIDI][0] / 8;
    barGraph();                //Display MIDI Chan number on bottom 2 rows
  }

  // READ MIDI note KNOB --------------------------------------------------------

  ntknob = EncodeReadO();
  if (ntknob != 0 && time - last_read_M > read_delay)
  {
    //   MIDI.sendNoteOff(MIDI_sets[activeMIDI][1], 0, MIDI_chan); // turn off note before changing it
    a = activeMIDI;
    playMIDIOff();

    MIDI_sets[activeMIDI][1] = MIDI_sets[activeMIDI][1] + ntknob;
    if (MIDI_sets [activeMIDI][1] > 127) {
      MIDI_sets [activeMIDI][1] = 127;
    }
    if (MIDI_sets[activeMIDI][1] < 1) {
      MIDI_sets[activeMIDI][1] = 1;
    }
    // play the new note
    runningStatus = 0; // send full MIDI note_on
    a = activeMIDI;
    playMIDINote();

    last_read_M = millis();

    // note number display

    dots_M = (MIDI_sets[activeMIDI][1] / 12) - 1; // which midi octave
    dots = (MIDI_sets[activeMIDI][1] % 12) + 1;    // which midi note
    M_displayDelay = displayDelay;

    switch (dots_M) {              // display octave as BINARY number on the right side of bottom row
      case 1:
        dots_octave = B00010000;
        break;
      case 2:
        dots_octave = B00100000;
        break;
      case 3:
        dots_octave = B00110000;
        break;
      case 4:
        dots_octave = B01000000;
        break;
      case 5:
        dots_octave = B01010000;
        break;
      case 6:
        dots_octave = B01100000;
        break;
      case 7:
        dots_octave = B01110000;
        break;
      case 8:
        dots_octave = B10000000;
        break;
      case 9:
        dots_octave = B10010000;
        break;
      case 10:
        dots_octave = B10100000;
        break;
      default:
        dots_octave = B00000000;
        break;
    }
    barGraph();
  }


  if (M_displayDelay < 2) {     // turn off MIDI update display and write to EEPROM
    M_displayDelay = 1;
  }

  // ------------------------------MIDI EEPROM Write-----------------------------------

  // Save new MIDI settings - saves when display countdown = 10 - reduces EEPROM writes
  // EEPROM.update() command wasn't working so a compare is done before writing.
  // Write is only done on a changed parameter

  if (M_displayDelay == 10) {              // Save new MIDI settings - saves when display countdown = 10 - reduces EEPROM writes
    for (Update = 0; Update < 4; Update++)
    {
      //debug
      /* Serial.print("Update = ");
         Serial.print(Update);
         Serial.print(" - ");
         Serial.print(MIDI_chan);
         Serial.print(" - ");
         Serial.print(MIDI_sets[Update][0]);
         Serial.print(" - ");
         Serial.print(MIDI_sets[Update][1]);
         Serial.println();
      */

      if (EEPROM.read(Update + 13) != MIDI_chan) {
        EEPROM.write((Update + 13), MIDI_chan); // write midi channel
      }
      if (EEPROM.read(Update + 17) != MIDI_sets[Update][0]) {
        EEPROM.write((Update + 17), MIDI_sets[Update][0]); // write velocity setting for active seq channel
      }
      if (EEPROM.read(Update + 21) != MIDI_sets[Update][1]) {
        EEPROM.write((Update + 21), MIDI_sets[Update][1]); // write note setting for active seq channel
      }
    }
  }
}

//END
