// Read the switches routing for EEPROM mode

/*
  Long Press of encoder 1 returns encoders to Euclidian mode
  Long Press of encoder 2 recalls selected preset
  Long Press of encoder 3 writes current settings to selected preset
*/

// read switches in PRESET mode

// switches are active only in long press

void P_read_switches()
{

  // -------------- test for long press in Preset mode ---------------------

  // switch pressed - start timing it

  if (channel_switch != 3 && old_channel_switch == 3) {
    long_press = time;
  }

  // switch held - how long

  if (channel_switch != 3 && old_channel_switch != 3) {

    switch (channel_switch + 1) {
      case 1:                      // long press return to Euclidian mode
        if (time - long_press > 2000) {
          MIDI_Mode = 1;
          lc.setRow(0, 7, B0000000);
          exit();
        }
      case 2:                      // recall selected preset
        preset_wait();
        if ((time - long_press) > Write_delay)
        {
          MIDI_Mode = Previous_Mode; //return to mode left to enter preset mode
          //lc.setRow(0, 7, B11110000);
          //Serial.println();
          //Serial.print("READ");
          //Serial.println();
          recal_EEPROM ();
          exit();
        }
        break;
      case 3:                      // write to selected preset
        preset_wait();
        if ((time - long_press) > Write_delay)
        {
          MIDI_Mode = Previous_Mode; //return to mode left to enter preset mode
          //Serial.println();
          //Serial.print("WRITE");
          //Serial.println();
          //lc.setRow(0, 7, B00001111);
          store_EEPROM();
          exit();
        }
        break;
    }
  }

  // Switch released - set preset number to 1 and redraw dislay
  if (channel_switch == 3 && old_channel_switch != 3) {
 //   Preset_number = 1;
    dots_octave = B11011011;                       //set row 8 to preset function warning
    dots = Preset_number;
    barGraph();                                    //Display preset number on row 7 solid line on 8
  }

  old_channel_switch = channel_switch; // store state this loop to compare next time
}

// -------------------------------- Subroutines -------------------------

// reset display befre exiting PRESET MODE
void exit()
{
  long_press = time;
  lc.setRow(0, 6, false); //clear row 7
  lc.setRow(0, 7, false); //clear row 8
  M_displayDelay = 1; // release bottom row of diaplay
}


// Animate wait countdown for read/write
void preset_wait()
{
  dots = (time - long_press) / (Write_delay / 8);
  dots_octave = B11011011;
  barGraph();

  if (channel_switch == 3 && old_channel_switch == 3) {  // switch released reset counter and display
    dots = Preset_number;
    dots_octave = B11011011;
    barGraph();                                    //Display preset number on row 7 solid line on 8
  }
}

//END
